<?php

namespace Drupal\user_inactivity_revoke_roles\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\Role;
use Drupal\user\RoleInterface;

/**
 * User inactivity settings form.
 */
class UserInactivitySettingsForm extends ConfigFormBase {

  /**
   * {@inheritDoc}
   */
  public function getFormId(): string {
    return 'user_inactivity_settings_form';
  }

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames(): array {
    return ['user_inactivity_revoke_roles.settings'];
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('user_inactivity_revoke_roles.settings');

    $form['revoke_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable automatic role revocation'),
      '#default_value' => $config->get('revoke_enabled') ?? FALSE,
    ];

    $form['chunk_size'] = [
      '#type' => 'number',
      '#title' => $this->t('Users to process per run'),
      '#default_value' => $config->get('chunk_size') ?? 20,
      '#min' => 1,
      '#description' => $this->t('Maximum number of users to process in one cron run. Helps avoid timeouts.'),
      '#states' => [
        'visible' => [
          ':input[name="revoke_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['inactive_days'] = [
      '#type' => 'number',
      '#title' => $this->t('Days of inactivity'),
      '#description' => $this->t('Users who haven’t logged in within this many days will have the selected roles revoked.'),
      '#min' => 1,
      '#default_value' => $config->get('inactive_days') ?? 30,
      '#states' => [
        'visible' => [
          ':input[name="revoke_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $roles = Role::loadMultiple();
    $excluded_roles = [
      RoleInterface::ANONYMOUS_ID,
      RoleInterface::AUTHENTICATED_ID,
    ];
    $role_options = [];
    foreach ($roles as $id => $role) {
      if (!in_array($id, $excluded_roles, TRUE)) {
        $role_options[$id] = $role->label();
      }
    }

    $form['target_roles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Roles to evaluate'),
      '#description' => $this->t('Select the roles that should be revoked for inactive users. If none selected nothing will happen.'),
      '#options' => $role_options,
      '#default_value' => $config->get('target_roles') ?? [],
      '#states' => [
        'visible' => [
          ':input[name="revoke_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritDoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('user_inactivity_revoke_roles.settings')
      ->set('revoke_enabled', $form_state->getValue('revoke_enabled'))
      ->set('chunk_size', $form_state->getValue('chunk_size'))
      ->set('inactive_days', $form_state->getValue('inactive_days'))
      ->set('target_roles', array_filter($form_state->getValue('target_roles')))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
